@@ -25,6 +25,7 @@ from sklearn.metrics import (
 )
 from tensorboardX import SummaryWriter
 from tokenizers import BertWordPieceTokenizer, ByteLevelBPETokenizer
+from tokenizers.implementations import SentencePieceBPETokenizer
 from tokenizers.processors import BertProcessing
 from torch.nn.utils.rnn import pad_sequence
 from torch.utils.data import DataLoader, Dataset, RandomSampler, SequentialSampler
@@ -47,6 +48,9 @@ from transformers import (
     BertConfig,
     BertForMaskedLM,
     BertTokenizer,
+    BigBirdConfig,
+    BigBirdForMaskedLM,
+    BigBirdTokenizer,
     CamembertConfig,
     CamembertForMaskedLM,
     CamembertTokenizer,
@@ -71,6 +75,9 @@ from transformers import (
     RobertaConfig,
     RobertaForMaskedLM,
     RobertaTokenizer,
+    XLMRobertaConfig,
+    XLMRobertaForMaskedLM,
+    XLMRobertaTokenizer
 )
 from transformers.data.datasets.language_modeling import LineByLineTextDataset, TextDataset
 
@@ -78,7 +85,7 @@ from simpletransformers.config.global_args import global_args
 from simpletransformers.config.model_args import LanguageModelingArgs
 from simpletransformers.config.utils import sweep_config_to_sweep_values
 from simpletransformers.custom_models.models import ElectraForLanguageModelingModel
-from simpletransformers.language_modeling.language_modeling_utils import SimpleDataset, mask_tokens
+from simpletransformers.language_modeling.language_modeling_utils import SimpleDataset, load_hf_dataset, mask_tokens
 
 try:
     import wandb
@@ -92,6 +99,7 @@ logger = logging.getLogger(__name__)
 MODEL_CLASSES = {
     "auto": (AutoConfig, AutoModelWithLMHead, AutoTokenizer),
     "bert": (BertConfig, BertForMaskedLM, BertTokenizer),
+    "bigbird": (BigBirdConfig, BigBirdForMaskedLM, BigBirdTokenizer),
     "camembert": (CamembertConfig, CamembertForMaskedLM, CamembertTokenizer),
     "distilbert": (DistilBertConfig, DistilBertForMaskedLM, DistilBertTokenizer),
     "electra": (ElectraConfig, ElectraForLanguageModelingModel, ElectraTokenizer),
@@ -99,6 +107,7 @@ MODEL_CLASSES = {
     "longformer": (LongformerConfig, LongformerForMaskedLM, LongformerTokenizer),
     "openai-gpt": (OpenAIGPTConfig, OpenAIGPTLMHeadModel, OpenAIGPTTokenizer),
     "roberta": (RobertaConfig, RobertaForMaskedLM, RobertaTokenizer),
+    "xlmroberta": (XLMRobertaConfig, XLMRobertaForMaskedLM, XLMRobertaTokenizer),
 }
 
 
@@ -281,7 +290,9 @@ class LanguageModelingModel:
                         discriminator_config=self.discriminator_config,
                         **kwargs,
                     )
-                    self.model.load_state_dict(torch.load(os.path.join(self.args.model_name, "pytorch_model.bin")))
+                    self.model.load_state_dict(
+                        torch.load(os.path.join(self.args.model_name, "pytorch_model.bin"), map_location=self.device)
+                    )
             else:
                 self.model = model_class.from_pretrained(
                     model_name, config=self.config, cache_dir=self.args.cache_dir, **kwargs,
@@ -417,9 +428,13 @@ class LanguageModelingModel:
         if self.is_world_master():
             tb_writer = SummaryWriter(logdir=args.tensorboard_dir)
         train_sampler = RandomSampler(train_dataset) if args.local_rank == -1 else DistributedSampler(train_dataset)
-        train_dataloader = DataLoader(
-            train_dataset, batch_size=args.train_batch_size, sampler=train_sampler, collate_fn=collate,
-        )
+        if self.args.use_hf_datasets:
+            # Inputs are already padded so default collation is fine
+            train_dataloader = DataLoader(train_dataset, batch_size=args.train_batch_size, sampler=train_sampler)
+        else:
+            train_dataloader = DataLoader(
+                train_dataset, batch_size=args.train_batch_size, sampler=train_sampler, collate_fn=collate,
+            )
 
         if args.max_steps > 0:
             t_total = args.max_steps
@@ -540,7 +555,7 @@ class LanguageModelingModel:
                 num_warmup_steps=args.warmup_steps,
                 num_training_steps=t_total,
                 lr_end=args.polynomial_decay_schedule_lr_end,
-                power=args.polynomial_decay_schedule_lr_end,
+                power=args.polynomial_decay_schedule_power,
             )
 
         else:
@@ -603,6 +618,7 @@ class LanguageModelingModel:
 
         if args.wandb_project:
             wandb.init(project=args.wandb_project, config={**asdict(args)}, **args.wandb_kwargs)
+            wandb.run._label(repo="simpletransformers")
             wandb.watch(self.model)
 
         if args.fp16:
@@ -629,6 +645,9 @@ class LanguageModelingModel:
                     steps_trained_in_current_epoch -= 1
                     continue
 
+                if self.args.use_hf_datasets:
+                    batch = batch["input_ids"]
+
                 inputs, labels = mask_tokens(batch, tokenizer, args) if args.mlm else (batch, batch)
                 inputs = inputs.to(self.device)
                 labels = labels.to(self.device)
@@ -733,7 +752,10 @@ class LanguageModelingModel:
 
                         if self.is_world_master():
                             for key, value in results.items():
-                                tb_writer.add_scalar("eval_{}".format(key), value, global_step)
+                                try:
+                                    tb_writer.add_scalar("eval_{}".format(key), value, global_step)
+                                except (NotImplementedError, AssertionError):
+                                    pass
 
                         output_dir_current = os.path.join(output_dir, "checkpoint-{}".format(global_step))
 
@@ -949,9 +971,13 @@ class LanguageModelingModel:
             return pad_sequence(examples, batch_first=True, padding_value=tokenizer.pad_token_id)
 
         eval_sampler = SequentialSampler(eval_dataset)
-        eval_dataloader = DataLoader(
-            eval_dataset, sampler=eval_sampler, batch_size=args.eval_batch_size, collate_fn=collate
-        )
+        if self.args.use_hf_datasets:
+            # Inputs are already padded so default collation is fine
+            eval_dataloader = DataLoader(eval_dataset, batch_size=args.train_batch_size, sampler=eval_sampler)
+        else:
+            eval_dataloader = DataLoader(
+                eval_dataset, batch_size=args.train_batch_size, sampler=eval_sampler, collate_fn=collate,
+            )
 
         if args.n_gpu > 1:
             model = torch.nn.DataParallel(model)
@@ -961,6 +987,9 @@ class LanguageModelingModel:
         model.eval()
 
         for batch in tqdm(eval_dataloader, disable=args.silent or silent, desc="Running Evaluation"):
+            if self.args.use_hf_datasets:
+                batch = batch["input_ids"]
+
             inputs, labels = mask_tokens(batch, tokenizer, args) if args.mlm else (batch, batch)
             inputs = inputs.to(self.device)
             labels = labels.to(self.device)
@@ -1008,7 +1037,10 @@ class LanguageModelingModel:
 
         mode = "dev" if evaluate else "train"
 
-        if args.dataset_class:
+        if self.args.use_hf_datasets:
+            dataset = load_hf_dataset(file_path, tokenizer, self.args)
+            return dataset
+        elif args.dataset_class:
             CustomDataset = args.dataset_class
             return CustomDataset(tokenizer, args, file_path, mode, args.block_size)
         else:
@@ -1083,6 +1115,36 @@ class LanguageModelingModel:
                 special_tokens=self.args.special_tokens,
                 wordpieces_prefix="##",
             )
+        elif self.args.model_type in ['bigbird', 'xlmroberta']:
+            # The google BigBird way
+            # Tokenizers sentencepiece does not build a BigBird compatible vocabulary model
+            import sentencepiece as spm
+            import shutil
+
+            os.makedirs(output_dir, exist_ok=True)
+            files = ",".join(train_files)
+
+            if self.args.model_type in ['xlmroberta']:
+                # </s>,<s>,<unk>,<pad> are built in -- leave as default
+                # XLMRoberta uses sentencepiece.bpe as a vocab model prefix
+                prefix='sentencepiece.bpe'
+                spm.SentencePieceTrainer.Train(
+                    f"--input={files} --user_defined_symbols='<mask>,<s>NOTUSED,</s>NOTUSED' --model_prefix={prefix} --vocab_size={self.args.vocab_size}")
+            else:
+                # </s>,<s>,<unk>,<pad> are built in -- leave as default
+                # BigBird uses spiece as a vocab model prefix
+                prefix = 'spiece'
+                spm.SentencePieceTrainer.Train(
+                    f"--input={files} --user_defined_symbols='[SEP],[CLS],[MASK]' --model_prefix=spiece --vocab_size={self.args.vocab_size}")
+
+            # SentencePiece There is no option for output path https://github.com/google/sentencepiece/blob/master/doc/options.md
+            if os.path.exists(output_dir + '/' + f'{prefix}.model'):
+                os.remove(output_dir + '/' + f'{prefix}.model')
+            shutil.move(src=f'{prefix}.model', dst=output_dir)
+
+            if os.path.exists(output_dir + '/' + f'{prefix}.vocab'):
+                os.remove(output_dir + '/' + f'{prefix}.vocab')
+            shutil.move(src=f'{prefix}.vocab', dst=output_dir)
         else:
             tokenizer = ByteLevelBPETokenizer(lowercase=self.args.do_lower_case)
 
@@ -1093,10 +1155,15 @@ class LanguageModelingModel:
                 special_tokens=self.args.special_tokens,
             )
 
-        os.makedirs(output_dir, exist_ok=True)
+        if self.args.model_type not in ['bigbird', 'xlmroberta']:
+            os.makedirs(output_dir, exist_ok=True)
 
-        tokenizer.save_model(output_dir)
-        logger.info(" Training of {} tokenizer complete. Saved to {}.".format(tokenizer_name, output_dir))
+            tokenizer.save_model(output_dir)
+            logger.info(
+                " Training of {} tokenizer complete. Saved to {}.".format(
+                    tokenizer_name, output_dir
+                )
+            )
 
         _, _, tokenizer_class = MODEL_CLASSES[self.args.model_type]
         tokenizer = tokenizer_class.from_pretrained(output_dir)
@@ -1121,6 +1188,7 @@ class LanguageModelingModel:
                     model_to_resize.resize_token_embeddings(len(self.tokenizer))
 
                 model_to_resize = self.model.module if hasattr(self.model, "module") else self.model
+
                 model_to_resize.resize_token_embeddings(len(self.tokenizer))
             except AttributeError:
                 pass
@@ -1129,7 +1197,9 @@ class LanguageModelingModel:
         if self.args.model_type == "electra":
             if not self.args.no_save:
                 if not output_dir:
-                    output_dir = os.path.join(self.args.output_dir, "discriminator_model")
+                    output_dir = os.path.join(
+                        self.args.output_dir, "discriminator_model"
+                    )
                 os.makedirs(output_dir, exist_ok=True)
                 model_to_save = (
                     self.model.discriminator_model.module
@@ -1180,7 +1250,9 @@ class LanguageModelingModel:
     def _get_last_metrics(self, metric_values):
         return {metric: values[-1] for metric, values in metric_values.items()}
 
-    def save_model(self, output_dir=None, optimizer=None, scheduler=None, model=None, results=None):
+    def save_model(
+        self, output_dir=None, optimizer=None, scheduler=None, model=None, results=None
+    ):
         if not self.is_world_master():
             return
         if not output_dir:
@@ -1192,15 +1264,25 @@ class LanguageModelingModel:
             model_to_save = model.module if hasattr(model, "module") else model
             if self.args.model_type in "electra":
                 os.makedirs(os.path.join(output_dir, "generator_config"), exist_ok=True)
-                os.makedirs(os.path.join(output_dir, "discriminator_config"), exist_ok=True)
-                self.generator_config.save_pretrained(os.path.join(output_dir, "generator_config"))
-                self.discriminator_config.save_pretrained(os.path.join(output_dir, "discriminator_config"))
+                os.makedirs(
+                    os.path.join(output_dir, "discriminator_config"), exist_ok=True
+                )
+                self.generator_config.save_pretrained(
+                    os.path.join(output_dir, "generator_config")
+                )
+                self.discriminator_config.save_pretrained(
+                    os.path.join(output_dir, "discriminator_config")
+                )
             model_to_save.save_pretrained(output_dir)
             self.tokenizer.save_pretrained(output_dir)
             torch.save(self.args, os.path.join(output_dir, "training_args.bin"))
             if optimizer and scheduler and self.args.save_optimizer_and_scheduler:
-                torch.save(optimizer.state_dict(), os.path.join(output_dir, "optimizer.pt"))
-                torch.save(scheduler.state_dict(), os.path.join(output_dir, "scheduler.pt"))
+                torch.save(
+                    optimizer.state_dict(), os.path.join(output_dir, "optimizer.pt")
+                )
+                torch.save(
+                    scheduler.state_dict(), os.path.join(output_dir, "scheduler.pt")
+                )
             self.save_model_args(output_dir)
 
         if results:
