@@ -4,7 +4,7 @@ from transformers.models.gpt2.modeling_gpt2 import GPT2Model, GPT2PreTrainedMode
 # supports both BERT & ROBERTA BASED MODELS
 class GPT2ForTextRepresentation(GPT2PreTrainedModel):
     r"""
-   Outputs: `List` of token vectors, 1 list of max_seq token vectors per sentence given
+    Outputs: `List` of token vectors, 1 list of max_seq token vectors per sentence given
     """  # noqa: ignore flake8"
 
     def __init__(self, config, weight=None):
@@ -16,7 +16,14 @@ class GPT2ForTextRepresentation(GPT2PreTrainedModel):
     def resize_token_embeddings(self, new_len):
         return self.gpt2.resize_token_embeddings(new_len)
 
-    def forward(self, input_ids=None, attention_mask=None, token_type_ids=None, position_ids=None, head_mask=None):
+    def forward(
+        self,
+        input_ids=None,
+        attention_mask=None,
+        token_type_ids=None,
+        position_ids=None,
+        head_mask=None,
+    ):
         outputs = self.gpt2(
             input_ids,
             attention_mask=attention_mask,
