@@ -12,10 +12,67 @@ from tokenizers.processors import BertProcessing
 from torch.utils.data import Dataset
 from tqdm.auto import tqdm
 from transformers import PreTrainedTokenizer
+from datasets import load_dataset
+from datasets import Dataset as HFDataset
+
 
 logger = logging.getLogger(__name__)
 
 
+def preprocess_batch_for_hf_dataset(dataset, tokenizer, args):
+    if args.preprocess_inputs:
+        return tokenizer.prepare_seq2seq_batch(
+            src_texts=[
+                prefix + ": " + input_text
+                for prefix, input_text in zip(dataset["prefix"], dataset["input_text"])
+            ],
+            tgt_texts=dataset["target_text"],
+            max_length=args.max_seq_length,
+            padding="max_length",
+            return_tensors="np",
+            truncation=True,
+        )
+    else:
+        return tokenizer.prepare_seq2seq_batch(
+            src_texts=[
+                prefix + input_text
+                for prefix, input_text in zip(dataset["prefix"], dataset["input_text"])
+            ],
+            tgt_texts=dataset["target_text"],
+            max_length=args.max_seq_length,
+            padding="max_length",
+            return_tensors="np",
+            truncation=True,
+        )
+
+
+def load_hf_dataset(data, tokenizer, args):
+    if isinstance(data, str):
+        dataset = load_dataset(
+            "csv",
+            data_files=data,
+            delimiter="\t",
+            download_mode="force_redownload"
+            if args.reprocess_input_data
+            else "reuse_dataset_if_exists",
+        )
+    else:
+        dataset = HFDataset.from_pandas(data)
+
+    dataset = dataset.map(
+        lambda x: preprocess_batch_for_hf_dataset(x, tokenizer=tokenizer, args=args),
+        batched=True,
+    )
+
+    dataset.set_format(type="pt", columns=["input_ids", "attention_mask"])
+
+    if isinstance(data, str):
+        # This is not necessarily a train dataset. The datasets library insists on calling it train.
+        return dataset["train"]
+    else:
+        return dataset
+
+
 def preprocess_data(data):
     prefix, input_text, target_text, tokenizer, args = data
 
@@ -73,7 +130,11 @@ def preprocess_data(data):
 class T5Dataset(Dataset):
     def __init__(self, tokenizer, args, data, mode):
         cached_features_file = os.path.join(
-            args.cache_dir, args.model_name.replace("/", "_") + "_cached_" + str(args.max_seq_length) + str(len(data)),
+            args.cache_dir,
+            args.model_name.replace("/", "_")
+            + "_cached_"
+            + str(args.max_seq_length)
+            + str(len(data)),
         )
 
         if os.path.exists(cached_features_file) and (
@@ -88,7 +149,9 @@ class T5Dataset(Dataset):
 
             data = [
                 (prefix, input_text, target_text, tokenizer, args)
-                for prefix, input_text, target_text in zip(data["prefix"], data["input_text"], data["target_text"])
+                for prefix, input_text, target_text in zip(
+                    data["prefix"], data["input_text"], data["target_text"]
+                )
             ]
 
             if (mode == "train" and args.use_multiprocessing) or (
@@ -101,13 +164,21 @@ class T5Dataset(Dataset):
 
                 with Pool(args.process_count) as p:
                     self.examples = list(
-                        tqdm(p.imap(preprocess_data, data, chunksize=chunksize), total=len(data), disable=args.silent,)
+                        tqdm(
+                            p.imap(preprocess_data, data, chunksize=chunksize),
+                            total=len(data),
+                            disable=args.silent,
+                        )
                     )
             else:
-                self.examples = [preprocess_data(d) for d in tqdm(data, disable=args.silent)]
+                self.examples = [
+                    preprocess_data(d) for d in tqdm(data, disable=args.silent)
+                ]
 
             if not args.no_cache:
-                logger.info(" Saving features into cached file %s", cached_features_file)
+                logger.info(
+                    " Saving features into cached file %s", cached_features_file
+                )
                 with open(cached_features_file, "wb") as handle:
                     pickle.dump(self.examples, handle, protocol=pickle.HIGHEST_PROTOCOL)
 
